Update docs for *ExecutorService to reference LooperMode instead of RealisticLooper.

PiperOrigin-RevId: 244926086
diff --git a/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/InlineExecutorService.java b/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/InlineExecutorService.java
index d64285c..cbc0761 100644
--- a/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/InlineExecutorService.java
+++ b/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/InlineExecutorService.java
@@ -11,11 +11,13 @@
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
+import org.robolectric.annotation.LooperMode;
 
 /**
  * Executor service that executes posted tasks as soon as they are posted.
  *
  * Intended to be a replacement for {@link RoboExecutorService} when using the RealisticLooper.
  * Unlike {@link RoboExecutorService}, will execute tasks on a background thread. This is useful
  * to test Android code that enforces it runs off the main thread.
  *
@@ -11,11 +11,13 @@
  * Executor service that executes posted tasks as soon as they are posted.
  *
- * Intended to be a replacement for {@link RoboExecutorService} when using the RealisticLooper.
+ * Intended to be a replacement for {@link RoboExecutorService} when using
+ * {@link LooperMode.Mode#PAUSED}.
  * Unlike {@link RoboExecutorService}, will execute tasks on a background thread. This is useful
  * to test Android code that enforces it runs off the main thread.
diff --git a/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/PausedExecutorService.java b/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/PausedExecutorService.java
index b75c1e7..0f858b4 100644
--- a/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/PausedExecutorService.java
+++ b/shadows/framework/src/main/java/org/robolectric/android/util/concurrent/PausedExecutorService.java
@@ -15,6 +15,7 @@
 import java.util.concurrent.Future;
 import java.util.concurrent.RunnableFuture;
 import java.util.concurrent.TimeUnit;
+import org.robolectric.annotation.LooperMode;
 import org.robolectric.util.Logger;
 
 /**
@@ -22,7 +23,8 @@
  *
  * Users must explicitly call {@link runAll()} to execute all pending tasks.
  *
  * Intended to be a replacement for {@link RoboExecutorService} when using the RealisticLooper.
  * Unlike {@link RoboExecutorService}, will execute tasks on a background thread. This is useful
  * to test Android code that enforces it runs off the main thread.
  *
@@ -22,7 +23,8 @@
  * Users must explicitly call {@link runAll()} to execute all pending tasks.
  *
- * Intended to be a replacement for {@link RoboExecutorService} when using the RealisticLooper.
+ * Intended to be a replacement for {@link RoboExecutorService} when using
+ * {@link LooperMode.Mode#PAUSED}.
  * Unlike {@link RoboExecutorService}, will execute tasks on a background thread. This is useful
  * to test Android code that enforces it runs off the main thread.